<h1 align="center">
  <br>
  <a href="https://bitbucket.org/romariojashari/uc/src"><img src="https://www.utilitycloud.us/hubfs/Utility%20Cloud%20%7C%20Utility%20Asset%20Management%20Software-01.svg" alt="Utility Cloud Logo"></a>
  <br>
  <br>
  Utility Cloud Python Library ( 0.0.1 release)
  <br>
</h1>

This python library is used to access & interact with the **[Utility Cloud's](https://www.utilitycloud.us)** [API](https://documenter.getpostman.com/view/10329688/SzKSUL4K?version=latest). It is necessary for bulk editing assets, asset classes, workflows, workflow fields, work orders, etc... Once a client asked us about it, we decided to make it public, free & available for everyone to use.


# Installation

Install from the recommended package installer, **pip**.

[https://pypi.org/project/utilitycloud/](https://pypi.org/project/utilitycloud/)

```sh
pip install utilitycloud
```
# License
Licensed under MIT.

# A Work In Progress
If you have any questions [contact us](https://www.utilitycloud.us/contact-us)

